==> jc-1.4.0.tar.gz: javax/security/auth/login/NullConfiguration.h <==
// final class javax.security.auth.login.NullConfiguration

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2ef6b4ae807df814 javax_security_auth_login_Configuration
// @dep_class faa991795405282f javax_security_auth_login_NullConfiguration

// header file dependencies
// @dep_header javax_security_auth_login_Configuration

#include "javax/security/auth/login/Configuration.h"

#ifndef _JC_javax_security_auth_login_NullConfiguration_H_
#define _JC_javax_security_auth_login_NullConfiguration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_login_NullConfiguration$sub_refs	_jc_javax_security_auth_login_NullConfiguration$sub_refs;
typedef struct _jc_javax_security_auth_login_NullConfiguration$sub_nonrefs	_jc_javax_security_auth_login_NullConfiguration$sub_nonrefs;
typedef struct _jc_javax_security_auth_login_NullConfiguration$refs	_jc_javax_security_auth_login_NullConfiguration$refs;
typedef struct _jc_javax_security_auth_login_NullConfiguration$nonrefs	_jc_javax_security_auth_login_NullConfiguration$nonrefs;
typedef struct _jc_javax_security_auth_login_NullConfiguration$object	_jc_javax_security_auth_login_NullConfiguration$object;

typedef const struct _jc_javax_security_auth_login_NullConfiguration$vmethods	_jc_javax_security_auth_login_NullConfiguration$vmethods;
typedef const struct _jc_javax_security_auth_login_NullConfiguration$vtable	_jc_javax_security_auth_login_NullConfiguration$vtable;
typedef const struct _jc_javax_security_auth_login_NullConfiguration$vtype	_jc_javax_security_auth_login_NullConfiguration$vtype;

// Constructors
extern void _jc_javax_security_auth_login_NullConfiguration$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_auth_login_NullConfiguration$object *);

// Virtual methods
extern _jc_object_array *_jc_javax_security_auth_login_NullConfiguration$method$getAppConfigurationEntry$fcb698d120847e70(_jc_env *, struct _jc_javax_security_auth_login_NullConfiguration$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_security_auth_login_NullConfiguration$method$refresh$23f3d9d8f6b36945(_jc_env *, struct _jc_javax_security_auth_login_NullConfiguration$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_login_NullConfiguration$method_info$getAppConfigurationEntry$fcb698d120847e70;
extern _jc_method _jc_javax_security_auth_login_NullConfiguration$method_info$refresh$23f3d9d8f6b36945;

// Virtual methods structure
struct _jc_javax_security_auth_login_NullConfiguration$vmethods {
	_jc_object_array	*(*getAppConfigurationEntry$fcb698d120847e70)(_jc_env *, struct _jc_javax_security_auth_login_NullConfiguration$object *, struct _jc_java_lang_String$object *);
	void	(*refresh$23f3d9d8f6b36945)(_jc_env *, struct _jc_javax_security_auth_login_NullConfiguration$object *);
};

// Vtable
struct _jc_javax_security_auth_login_NullConfiguration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_login_Configuration$vmethods	javax_security_auth_login_Configuration;
	_jc_javax_security_auth_login_NullConfiguration$vmethods	javax_security_auth_login_NullConfiguration;
};

// Vtype
struct _jc_javax_security_auth_login_NullConfiguration$vtype {
	_jc_type			type;
	_jc_javax_security_auth_login_NullConfiguration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_login_NullConfiguration$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_auth_login_NullConfiguration$refs {
    _jc_javax_security_auth_login_NullConfiguration$sub_refs	javax_security_auth_login_NullConfiguration;
    _jc_javax_security_auth_login_Configuration$sub_refs	javax_security_auth_login_Configuration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_login_NullConfiguration$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_login_NullConfiguration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_login_Configuration$sub_nonrefs	javax_security_auth_login_Configuration;
    _jc_javax_security_auth_login_NullConfiguration$sub_nonrefs	javax_security_auth_login_NullConfiguration;
};

// Object instance structure
struct _jc_javax_security_auth_login_NullConfiguration$object {
	_jc_javax_security_auth_login_NullConfiguration$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_login_NullConfiguration$vtype	*vtype;
	_jc_javax_security_auth_login_NullConfiguration$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_login_NullConfiguration$vtype _jc_javax_security_auth_login_NullConfiguration$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_login_NullConfiguration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_login_NullConfiguration$class_object;

#endif	/* _JC_javax_security_auth_login_NullConfiguration_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/login/NullConfiguration.h <==
// final class javax.security.auth.login.NullConfiguration

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2ef6b4ae807df814 javax_security_auth_login_Configuration
// @dep_class faa991795405282f javax_security_auth_login_NullConfiguration

// header file dependencies
// @dep_header javax_security_auth_login_Configuration

#include "javax/security/auth/login/Configuration.h"

#ifndef _JC_javax_security_auth_login_NullConfiguration_H_
#define _JC_javax_security_auth_login_NullConfiguration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_login_NullConfiguration$sub_refs	_jc_javax_security_auth_login_NullConfiguration$sub_refs;
typedef struct _jc_javax_security_auth_login_NullConfiguration$sub_nonrefs	_jc_javax_security_auth_login_NullConfiguration$sub_nonrefs;
typedef struct _jc_javax_security_auth_login_NullConfiguration$refs	_jc_javax_security_auth_login_NullConfiguration$refs;
typedef struct _jc_javax_security_auth_login_NullConfiguration$nonrefs	_jc_javax_security_auth_login_NullConfiguration$nonrefs;
typedef struct _jc_javax_security_auth_login_NullConfiguration$object	_jc_javax_security_auth_login_NullConfiguration$object;

typedef const struct _jc_javax_security_auth_login_NullConfiguration$vmethods	_jc_javax_security_auth_login_NullConfiguration$vmethods;
typedef const struct _jc_javax_security_auth_login_NullConfiguration$vtable	_jc_javax_security_auth_login_NullConfiguration$vtable;
typedef const struct _jc_javax_security_auth_login_NullConfiguration$vtype	_jc_javax_security_auth_login_NullConfiguration$vtype;

// Constructors
extern void _jc_javax_security_auth_login_NullConfiguration$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_auth_login_NullConfiguration$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_javax_security_auth_login_NullConfiguration$method$getAppConfigurationEntry$fcb698d120847e70(_jc_env *, struct _jc_javax_security_auth_login_NullConfiguration$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_login_NullConfiguration$method$refresh$23f3d9d8f6b36945(_jc_env *, struct _jc_javax_security_auth_login_NullConfiguration$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_login_NullConfiguration$method_info$getAppConfigurationEntry$fcb698d120847e70;
extern _jc_method _jc_javax_security_auth_login_NullConfiguration$method_info$refresh$23f3d9d8f6b36945;

// Virtual methods structure
struct _jc_javax_security_auth_login_NullConfiguration$vmethods {
	_jc_object_array	*(*getAppConfigurationEntry$fcb698d120847e70)(_jc_env *, struct _jc_javax_security_auth_login_NullConfiguration$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*refresh$23f3d9d8f6b36945)(_jc_env *, struct _jc_javax_security_auth_login_NullConfiguration$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_auth_login_NullConfiguration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_login_Configuration$vmethods	javax_security_auth_login_Configuration;
	_jc_javax_security_auth_login_NullConfiguration$vmethods	javax_security_auth_login_NullConfiguration;
};

// Vtype
struct _jc_javax_security_auth_login_NullConfiguration$vtype {
	_jc_type			type;
	_jc_javax_security_auth_login_NullConfiguration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_login_NullConfiguration$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_auth_login_NullConfiguration$refs {
    _jc_javax_security_auth_login_NullConfiguration$sub_refs	javax_security_auth_login_NullConfiguration;
    _jc_javax_security_auth_login_Configuration$sub_refs	javax_security_auth_login_Configuration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_login_NullConfiguration$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_login_NullConfiguration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_login_Configuration$sub_nonrefs	javax_security_auth_login_Configuration;
    _jc_javax_security_auth_login_NullConfiguration$sub_nonrefs	javax_security_auth_login_NullConfiguration;
};

// Object instance structure
struct _jc_javax_security_auth_login_NullConfiguration$object {
	_jc_javax_security_auth_login_NullConfiguration$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_login_NullConfiguration$vtype	*vtype;
	_jc_javax_security_auth_login_NullConfiguration$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_login_NullConfiguration$vtype _jc_javax_security_auth_login_NullConfiguration$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_login_NullConfiguration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_login_NullConfiguration$class_object;

#endif	/* _JC_javax_security_auth_login_NullConfiguration_H_ */
